@@ -11,16 +11,18 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #ifndef	ATLANTIC_ATLANTICDAEMON_H
 #define	ATLANTIC_ATLANTICDAEMON_H
 
+#include <qptrlist.h>
+
 class QSocket;
 
 class AtlanticCore;
-
+class AtlanticClient;
 class ServerSocket;
 
 class AtlanticDaemon : public QObject
@@ -29,16 +31,18 @@ Q_OBJECT
 
 public:
 	AtlanticDaemon();
-
+    ~AtlanticDaemon();
 private slots:
 	void monopigatorRegister();
 	void monopigatorConnected();
+	void newClient(AtlanticClient *client);
+	void clientInput(AtlanticClient *client, const QString &data);
 
 private:
 	QSocket *m_monopigatorSocket;
 	ServerSocket *m_serverSocket;
 	AtlanticCore *m_atlanticCore;
-
+	QPtrList<AtlanticClient> m_clients;
 };
 
 #endif
