@@ -11,8 +11,8 @@
 //
 // You should have received a copy of the GNU Lesser General Public License
 // along with this library; see the file COPYING.LIB.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include "trade.h"
 #include "trade.moc"
@@ -38,29 +38,20 @@ int Trade::revision() const
 
 void Trade::addPlayer(Player *player)
 {
-	mPlayers.append(player);
 	m_playerAcceptMap[player] = false;
 }
 
 void Trade::removePlayer(Player *player)
 {
-	mPlayers.remove(player);
 	m_playerAcceptMap[player] = false;
 }
 
-QPtrList<Player> Trade::players() const
-{
-	return mPlayers;
-}
-
-unsigned int Trade::acceptCount()
+unsigned int Trade::count( bool acceptOnly )
 {
 	unsigned int count = 0;
 	for (QMapIterator<Player *, bool> it = m_playerAcceptMap.begin() ; it != m_playerAcceptMap.end() ; ++it)
-	{
-		if (it.data())
+		if ( !acceptOnly || it.data() )
 			count++;
-	}
 	return count;
 }
 
