@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -29,12 +29,14 @@
 #include <qvbox.h>
 #include <qlabel.h>
 
+#include <kapplication.h>
 #include <kscoredialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kglobal.h>
 #include <ksimpleconfig.h>
+#include <kglobalsettings.h>
 
 Options settings;
 
@@ -82,14 +84,28 @@ void GameWidget::getButton (int button)
     feld->startAnimation ((Feld::Direction)button);
 }
 
+void GameWidget::doUndo ()
+{
+  feld->doUndo ();
+}
+
+void GameWidget::doRedo ()
+{
+  feld->doRedo ();
+}
+
 void GameWidget::gameOver(int moves) {
     KMessageBox::information(this, i18n("You solved level %1 with %2 moves!").arg(level).arg(moves), i18n("Congratulations"));
 
+    KScoreDialog high(KScoreDialog::Name | KScoreDialog::Score, this);
+    high.setCaption(i18n("Level %1 Highscores").arg(level));
+    high.setConfigGroup(QString("Highscores Level %1").arg(level));
+
     KScoreDialog::FieldInfo scoreInfo;
 
-    if (high->addScore(moves, scoreInfo, true, true))
+    if (high.addScore(moves, scoreInfo, true, true))
     {
-       high->exec();
+       high.exec();
     }
     updateLevel(level+1);
 }
@@ -112,13 +128,11 @@ void GameWidget::updateLevel (int l)
     cfg.setGroup("Level");
     feld->load(cfg);
 
-    QString group = QString("High Scores Level %1").arg(level);
-    high->setConfigGroup(group);
-    QString caption = i18n("Level %1 High Scores").arg(level);
-    high->setCaption(caption);
-    highest.setNum(high->highScore());
+    highScore->setConfigGroup(QString("High Scores Level %1").arg(level));
+    highest.setNum(highScore->highScore());
 
-    hs->setText(highest);
+    if (highest != "0" ) hs->setText(highest);
+    else hs->setText("-");
     ys->setText("0");
     scrl->setValue(level);
 
@@ -150,9 +164,8 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
     top->addWidget(vb);
 
     // scrollbar
-    scrl = new QScrollBar(1, nlevels, 1, 
+    scrl = new QScrollBar(1, nlevels, 1,
 			5, 1, QScrollBar::Horizontal, vb, "scrl" );
-    // scrl->setGeometry( MPOSX, 50, 160, 16 );
     connect (scrl, SIGNAL (valueChanged (int)), SLOT (updateLevel (int)));
 
     // molekl
@@ -161,19 +174,25 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
 
     connect (feld, SIGNAL (gameOver(int)), SLOT(gameOver(int)));
     connect (feld, SIGNAL (sendMoves(int)), SLOT(getMoves(int)));
+    connect (feld, SIGNAL (enableRedo(bool)), SIGNAL(enableRedo(bool)));
+    connect (feld, SIGNAL (enableUndo(bool)), SIGNAL(enableUndo(bool)));
+
+    highScore = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score, this);
 
     // the score group
     QGroupBox *bg = new QGroupBox (i18n("Score"), vb, "bg");
-    bg->setGeometry (MPOSX, 300, 160, 160);
     QBoxLayout *slay = new QVBoxLayout (bg, 10);
 
     slay->addSpacing(10);
 
-    slay->addWidget(new QLabel(i18n("Highest score:"), bg));
+    slay->addWidget(new QLabel(i18n("Highscore:"), bg));
+
+    QFont headerFont = KGlobalSettings::generalFont();
+    headerFont.setBold(true);
 
     hs = new QLabel (highest, bg);
     hs->setAlignment(Qt::AlignRight);
-    hs->setFont(QFont("Helvetica", 18, QFont::Bold));
+    hs->setFont(headerFont);
     slay->addWidget(hs);
 
     slay->addSpacing(10);
@@ -182,11 +201,9 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
 
     ys = new QLabel (current, bg);
     ys->setAlignment(Qt::AlignRight);
-    ys->setFont(QFont("Helvetica", 18, QFont::Bold));
+    ys->setFont(headerFont);
     slay->addWidget(ys);
 
-    high = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score, this);
-
     updateLevel(1);
 
     KConfig *config = KGlobal::config();
@@ -195,14 +212,7 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
     if (settings.anim_speed < 1 || settings.anim_speed > MAX_SPEED)
 	settings.anim_speed = 1;
 
-    config->setGroup("level1");
-    highest = config->readEntry("Moves0", "100");
-
-    config->setGroup("Colors");
-
     settings.changed = false;
-
-    setMinimumSize(665, 471);
 }
 
 GameWidget::~GameWidget()
@@ -211,7 +221,10 @@ GameWidget::~GameWidget()
 
 void GameWidget::showHighscores ()
 {
-    high->exec();
+    KScoreDialog high(KScoreDialog::Name | KScoreDialog::Score, this);
+    high.setCaption(i18n("Level %1 Highscores").arg(level));
+    high.setConfigGroup(QString("Highscores Level %1").arg(level));
+    high.exec();
 }
 
 #include "gamewidget.moc"
