@@ -20,6 +20,10 @@ class GameWidget : public QWidget
 
     ~GameWidget();
 
+ signals:
+    void enableRedo(bool enable);
+    void enableUndo(bool enable);
+
  public slots:
     // bringt level auf neuesten stand
     void updateLevel (int);
@@ -44,6 +48,8 @@ class GameWidget : public QWidget
     void moveRight();
     void nextAtom();
     void previousAtom();
+    void doUndo ();
+    void doRedo ();
 
  protected:
 
