@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgoffline.cpp 367604 2004-12-01 13:47:56Z binner $
+  $Id: kbgoffline.cpp 465369 2005-09-29 14:33:08Z mueller $
 
 */
 
@@ -695,12 +695,12 @@ bool KBgEngineOffline::queryClose()
     if (!d->mGameFlag)
         return true;
 
-    switch (KMessageBox::warningYesNo((QWidget *)parent(),
+    switch (KMessageBox::warningContinueCancel((QWidget *)parent(),
                                       i18n("In the middle of a game. "
-                                           "Really quit?"))) {
-    case KMessageBox::Yes :
+                                           "Really quit?"), QString::null, KStdGuiItem::quit())) {
+    case KMessageBox::Continue :
         return TRUE;
-    case KMessageBox::No :
+    case KMessageBox::Cancel :
         return FALSE;
     default: // cancel
         return FALSE;
