@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.h 465369 2005-09-29 14:33:08Z mueller $
+  $Id: kbg.h 640692 2007-03-08 20:28:37Z lueck $
 
 */
 
@@ -164,7 +164,6 @@ protected slots:
 	void showWWW(int t);
 
 	void wwwFIBS();
-	void wwwHome();
 	void wwwRule();
 
 	/**
@@ -204,7 +203,7 @@ private:
 	int currEngine;
 
 	QPopupMenu *dummyPopup;
-	enum HelpTpoics {FIBSHome, RuleHome, SelfHome, MaxHelpTopic};
+	enum HelpTopics {FIBSHome, RuleHome, MaxHelpTopic};
 	QString helpTopic[MaxHelpTopic][2];
 	KSelectAction *engineSet;
 
