@@ -314,7 +314,7 @@ void KBattleshipWindow::slotEnemyFieldClick(int fieldx, int fieldy)
 				slotStatusMsg(i18n("You won the game :)"));
 				m_stat->slotAddOwnWon();
 				slotUpdateHighscore();
-				switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+				switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"),QString::null,i18n("Restart"),i18n("Do Not Restart")))
 				{
 					case KMessageBox::Yes:
 						QTimer::singleShot(0, this, SLOT(slotRestartAI()));
@@ -715,7 +715,7 @@ void KBattleshipWindow::slotDeleteConnectDialog()
 
 void KBattleshipWindow::slotReplayRequest()
 {
-	switch(KMessageBox::questionYesNo(this, i18n("The client is asking to restart the game. Do you accept?")))
+	switch(KMessageBox::questionYesNo(this, i18n("The client is asking to restart the game. Do you accept?"),QString::null,i18n("Accept Restart"), i18n("Deny Restart")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -735,7 +735,7 @@ void KBattleshipWindow::slotReplayRequest()
 void KBattleshipWindow::slotServerReplay()
 {
 	KMessage *msg = new KMessage(KMessage::REPLAY);
-	switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+	switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"), QString::null, i18n("Restart"), i18n("Do Not Restart")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -761,7 +761,7 @@ void KBattleshipWindow::slotServerReplay()
 void KBattleshipWindow::slotClientReplay()
 {
 	KMessage *msg = new KMessage(KMessage::REPLAY);
-	switch(KMessageBox::questionYesNo(this, i18n("Do you want to ask the server restarting the game?")))
+	switch(KMessageBox::questionYesNo(this, i18n("Do you want to ask the server restarting the game?"), QString::null, i18n("Ask to Restart"), i18n("Do Not Ask")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -922,7 +922,7 @@ void KBattleshipWindow::slotLost(KMessage *msg)
 void KBattleshipWindow::slotSendEnemyFieldState(int fieldx, int fieldy)
 {
 	int data, showstate;
-	bool xokay = false, yokay = false;
+	bool xokay = false, yokay = false, is_kill = false;
 	typedef QValueList<int> DeathValueList;
 	DeathValueList deathList;
 
@@ -987,12 +987,12 @@ void KBattleshipWindow::slotSendEnemyFieldState(int fieldx, int fieldy)
 			msg->addField(QString("ystart"), QString::number(fieldy));
 			msg->addField(QString("ystop"), QString::number(fieldy));
 			msg->addField(QString("death"), QString("true"));
+			is_kill = true;
 		}
 	}
 
 	msg->addField(QString("fieldx"), QString::number(fieldx));
 	msg->addField(QString("fieldy"), QString::number(fieldy));
-	msg->addField(QString("fieldstate"), QString::number(data));
 
 	if(xokay)
 	{
@@ -1001,6 +1001,7 @@ void KBattleshipWindow::slotSendEnemyFieldState(int fieldx, int fieldy)
 		msg->addField(QString("ystart"), QString::number(fieldy));
 		msg->addField(QString("ystop"), QString::number(fieldy));
 		msg->addField(QString("death"), QString("true"));
+		is_kill = true;
 	}
 	else if(yokay)
 	{
@@ -1009,8 +1010,19 @@ void KBattleshipWindow::slotSendEnemyFieldState(int fieldx, int fieldy)
 		msg->addField(QString("ystart"), QString::number(deathList.first()));
 		msg->addField(QString("ystop"), QString::number(deathList.last()));
 		msg->addField(QString("death"), QString("true"));
+		is_kill = true;
 	}
 
+	if(is_kill)
+		// If sunk, reveal ship type
+		msg->addField(QString("fieldstate"), QString::number(data));
+	else if(showstate == KBattleField::HIT)
+		// On non-fatal hit, keep ship type secret
+		msg->addField(QString("fieldstate"), QString::number(1));
+	else /* showstate == KBattleField::WATER */
+		// Miss
+		msg->addField(QString("fieldstate"), QString::number(99));
+
 	if(m_connection->type() == KonnectionHandling::SERVER)
 		m_kbserver->sendMessage(msg);
 	else
@@ -1305,7 +1317,7 @@ void KBattleshipWindow::slotAIShootsAt(const QPoint pos)
 		m_stat->slotAddEnemyWon();
 		slotUpdateHighscore();
 		m_view->drawEnemyShipsAI(m_enemyshiplist); // let's show ai player ships
-		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"), QString::null, i18n("Restart"), i18n("Do Not Restart")))
 		{
 			case KMessageBox::Yes:
 				QTimer::singleShot(0, this, SLOT(slotRestartAI()));
