@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef GAME_H_INCLUDED
@@ -23,11 +23,9 @@
 #include <qcanvas.h>
 #include <qmemarray.h>
 
-#ifdef HAVE_ARTS
+#if HAVE_ARTS
 #include <arts/soundserver.h>
-#endif
 
-#ifdef HAVE_ARTS
 using namespace Arts;
 #endif
 
@@ -105,7 +103,7 @@ private:
 
    void setPixmaps( const QPixmap &tiles, const QPixmap &background );
    void emitBallCollisiton( Ball *ball, int x, int y, int tile )
-      { emit ballCollision( ball, x, y, tile ); };
+      { emit ballCollision( ball, x, y, tile ); }
 
 };
 
@@ -175,7 +173,7 @@ protected:
    int m_percent;
    bool m_pictured;
 
-#ifdef HAVE_ARTS
+#if HAVE_ARTS
    static SimpleSoundServer *m_artsServer;
 #endif
    static QString m_soundPath;
