@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qlayout.h>
@@ -26,8 +26,9 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
-#include <kscoredialog.h>
 #include <kstatusbar.h>
+#include <khighscore.h>
+#include <kexthighscore.h>
 
 #include "kbounce.h"
 #include "game.h"
@@ -129,6 +130,7 @@ void KJezzball::initXMLUI()
     KStdGameAction::highscores(this, SLOT(showHighscore()), actionCollection() );
     m_pauseButton = KStdGameAction::pause(this, SLOT(pauseGame()), actionCollection());
     KStdGameAction::end(this, SLOT(closeGame()), actionCollection());
+    KStdGameAction::configureHighscores(this, SLOT(configureHighscores()),actionCollection());
 
     new KAction( i18n("&Select Background Folder..."), 0, this, SLOT(selectBackground()),
                        actionCollection(), "background_select" );
@@ -175,7 +177,7 @@ void KJezzball::closeGame()
         int old_state = m_state;
         if (old_state == Running)
             pauseGame();
-        int ret = KMessageBox::questionYesNo( this, i18n("Do you really want to close the running game?") );
+        int ret = KMessageBox::questionYesNo( this, i18n("Do you really want to close the running game?"), QString::null, KStdGuiItem::close(), KStdGuiItem::cancel() );
         if ( ret==KMessageBox::Yes )
         {
             stopLevel();
@@ -232,13 +234,20 @@ void KJezzball::gameOverNow()
     highscore();
 }
 
+/**
+ * Bring up the standard kde high score configure dialog.
+ */
+void KJezzball::configureHighscores()
+{
+	KExtHighscore::configure(this);
+}
+
 /**
  * Bring up the standard kde high score dialog.
  */
 void KJezzball::showHighscore()
 {
-    KScoreDialog h(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
-    h.exec();
+    KExtHighscore::show(this);
 }
 
 /**
@@ -299,7 +308,7 @@ QPixmap KJezzball::getBackgroundPixmap()
     // list directory
     QDir dir( m_backgroundDir, "*.png *.jpg", QDir::Name|QDir::IgnoreCase, QDir::Files );
     if ( !dir.exists() ) {
-        kdDebug(1433) << "Directory not found" << endl;
+        kdDebug(12008) << "Directory not found" << endl;
         return QPixmap();
     }
 
@@ -473,17 +482,10 @@ i18n("On to level %1. Remember you get %2 lives this time!")).arg(m_game.level+1
 
 void KJezzball::highscore()
 {
-    KScoreDialog d(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
-
-    KScoreDialog::FieldInfo scoreInfo;
-
-    scoreInfo[KScoreDialog::Level].setNum(m_game.level);
-
-    if (!d.addScore(m_game.score, scoreInfo))
-       return;
-
-    // Show highscore & ask for name.
-    d.exec();
+    KExtHighscore::Score score(KExtHighscore::Won);
+    score.setScore(m_game.score);
+    score.setData("level", m_game.level);
+    KExtHighscore::submitScore(score, this);
 }
 
 #include "kbounce.moc"
