@@ -16,8 +16,6 @@
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kstdgameaction.h>
-#include <kedittoolbar.h>
-#include <kkeydialog.h>
 #include <kdebug.h>
 
 #include "AbTop.h"
@@ -86,11 +84,9 @@ AbTop::AbTop()
 
   // this creates the GUI
   setupActions();
-  createGUI();
   setupStatusBar();
   setMinimumSize(200,300);
 
-
   // RMB context menu
   connect( boardWidget, SIGNAL(rightButtonPressed(int,const QPoint&)),
 	   this, SLOT(rightButtonPressed(int,const QPoint&)) );
@@ -113,6 +109,7 @@ AbTop::AbTop()
 
   updateStatus();
   updateActions();
+  setupGUI();
 }
 
 AbTop::~AbTop()
@@ -166,7 +163,7 @@ void AbTop::setupActions()
 
   KToggleAction *ta;
 
-  ta = new KToggleAction( i18n("&Network Play"), "net", Key_N,
+  ta = new KToggleAction( i18n("&Network Play"), "network", Key_N,
 			  actionCollection(), "game_net");
   connect(ta, SIGNAL(toggled(bool)), this, SLOT(gameNetwork(bool)));
 
@@ -175,10 +172,6 @@ void AbTop::setupActions()
   connect(editAction, SIGNAL(toggled(bool)), this, SLOT( editModify(bool)));
 
   showMenubar = KStdAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
-  createStandardStatusBarAction();
-  setStandardToolBarMenuEnabled(true);
-  KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
-  KStdAction::configureToolbars(this,SLOT(configureToolbars()), actionCollection());
   KStdAction::saveOptions( this, SLOT(writeConfig()), actionCollection());
 
   KStdAction::preferences( this, SLOT(configure()), actionCollection());
@@ -235,31 +228,6 @@ void AbTop::configure()
   delete edlg;
 }
 
-
-
-void AbTop::configureKeys()
-{
-  KKeyDialog::configure(actionCollection(), this);
-}
-
-
-void AbTop::configureToolbars()
-{
-  saveMainWindowSettings(KGlobal::config(), "kedittoolbar settings"); // temp group
-  KEditToolbar dlg(actionCollection(), QString::null, true, this);
-  connect( &dlg, SIGNAL( newToolbarConfig() ),this,SLOT( newToolbarConfig() ) );
-  dlg.exec();
-  KGlobal::config()->deleteGroup( "kedittoolbar settings" ); // delete temp group
-}
-
-
-void AbTop::newToolbarConfig()
-{
-  createGUI();
-  applyMainWindowSettings(KGlobal::config(), "kedittoolbar settings");
-}
-
-
 /* Right Mouse button pressed in BoardWidget area */
 void AbTop::rightButtonPressed(int /* field */, const QPoint& pos)
 {
@@ -274,7 +242,7 @@ void AbTop::rightButtonPressed(int /* field */, const QPoint& pos)
  */
 void AbTop::readConfig()
 {
-  kdDebug() << "Reading config..." << endl;
+  kdDebug(12011) << "Reading config..." << endl;
 
   KConfig* config = kapp->config();
   config->setGroup("Options");
@@ -342,7 +310,7 @@ void AbTop::readProperties(KConfig *config)
 
 void AbTop::writeConfig()
 {
-  kdDebug() << "Writing config..." << endl;
+  kdDebug(12011) << "Writing config..." << endl;
 
   KConfig* config = kapp->config();
   config->setGroup("Options");
@@ -530,7 +498,7 @@ void AbTop::updateStatus()
 	.arg( (board->actColor() == Board::color1) ?
 	      i18n("Red"):i18n("Yellow") )
 	.arg( iPlayNow() ?
-	      i18n("I am thinking...") : i18n("It's your turn!") );
+	      i18n("I am thinking...") : i18n("It is your turn!") );
     }
   }
   statusLabel->setText(tmp);
@@ -979,7 +947,7 @@ void AbTop::setLevel(int l)
     levelAction->setCurrentItem(l);
     depth = l+2;
     board->setDepth(depth);
-  //  kdDebug() << "Level set to " << d << endl;
+  //  kdDebug(12011) << "Level set to " << d << endl;
 }
 
 void AbTop::setIPlay(int i)
