@@ -20,7 +20,7 @@ class Spy: public QWidget
 
 public:
   Spy(Board&);
-  ~Spy() {};
+  ~Spy() {}
 	
   enum { BoardCount = 5 };
 
