@@ -3,6 +3,9 @@
 
 #include "common/main.h"
 #include "common/factory.h"
+#include "board.h"
+#include "ai.h"
+#include "field.h"
 
 
 //-----------------------------------------------------------------------------
@@ -12,10 +15,12 @@ class FEFactory : public CommonFactory
     FEFactory();
 
  protected:
-    BaseBoard *createBoard(bool graphic, QWidget *parent);
-    BaseField *createField(QWidget *parent);
-    BaseInterface *createInterface(QWidget *parent);
-    AI *createAI();
+    virtual BaseBoard *createBoard(bool graphic, QWidget *parent)
+        { return new FEBoard(graphic, parent); }
+    virtual BaseField *createField(QWidget *parent)
+        { return new FEField(parent); }
+    virtual BaseInterface *createInterface(QWidget *parent);
+    virtual AI *createAI() { return new FEAI; }
 };
 
 //-----------------------------------------------------------------------------
