@@ -18,15 +18,15 @@
 
 #include <stdio.h>
 
-KGrFigure :: KGrFigure (int x, int y)
+KGrFigure :: KGrFigure (int px, int py)
 {
-  this->x = mem_x = x;
-  this->y = mem_y = y;
+  x = mem_x = px;
+  y = mem_y = py;
   relx = mem_relx = 0;
   rely = mem_rely = 0;
 
-  absx = x*16;
-  absy = y*16;
+  absx = px*16;
+  absy = py*16;
 
   nuggets = 0;
   status = STANDING;
@@ -76,6 +76,11 @@ int KGrFigure::gety()
   return absy;
 }
 
+Status KGrFigure::getStatus()
+{
+    return status;
+}
+
 void KGrFigure::init(int a,int b)
 {
   walkTimer->stop();
@@ -575,13 +580,19 @@ void KGrHero::walkTimeDone ()
       {
       collectNugget(); // und nehme evtl. Nugget
       }
-    showFigure();
+    showFigure();	// Is this REDUNDANT now?  See showFigure() below.
+			//////////////////////////////////////////////////
     }
   if (status == STANDING)
     if (!canStand()&&!hangAtPole())
       initFall(FALL1, FALLDELAY);
     else
       walkTimer->start ((WALKDELAY * NSPEED) / speed, TRUE);
+
+  // This additional showFigure() is to update the hero position after it is
+  // altered by the hero-enemy deadlock fix in standOnEnemy().  Messy, but ...
+  ////////////////////////////////////////////////////////////////////////////
+  showFigure();
   if(isInEnemy()) {
     walkTimer->stop();
     emit caughtHero();
@@ -615,8 +626,9 @@ void KGrHero::fallTimeDone()
 		direction = (actualPixmap == 19) ? RIGHT : LEFT;
 		if ((*playfield)[x][y]->whatIam() == POLE)
 		    actualPixmap = (direction == RIGHT)? RIGHTCLIMB1:LEFTCLIMB1;
-		else
-		    actualPixmap = (direction == RIGHT)? RIGHTWALK1:LEFTWALK1;
+		// else
+		    // Reduce jerkiness when descending over a falling enemy.
+		    // actualPixmap = (direction == RIGHT)? RIGHTWALK1:LEFTWALK1;
 	    }
 	}
 	showFigure();
@@ -628,8 +640,9 @@ void KGrHero::fallTimeDone()
 	    direction = (actualPixmap == 19) ? RIGHT : LEFT;
 	    if ((*playfield)[x][y]->whatIam() == POLE)
 		actualPixmap = (direction == RIGHT)? RIGHTCLIMB1:LEFTCLIMB1;
-	    else
-		actualPixmap = (direction == RIGHT)? RIGHTWALK1:LEFTWALK1;
+	    // else
+		// Reduce jerkiness when descending over a falling enemy.
+		// actualPixmap = (direction == RIGHT)? RIGHTWALK1:LEFTWALK1;
 	    walkTimer->start((WALKDELAY * NSPEED) / speed, TRUE);
 	}
 	else {
@@ -662,19 +675,39 @@ void KGrHero::dig(){
 }
 
 void KGrHero::digLeft(){
-  if (((*playfield)[x-1][y+1]->whatIam() == BRICK)&&
-      (((*playfield)[x-1][y]->whatIam() == HLADDER)||
-       ((*playfield)[x-1][y]->whatIam() == FREE)||
-       ((*playfield)[x-1][y]->whatIam() == HOLE)))
-    ((KGrBrick*)(*playfield)[x-1][y+1])->dig();
+  int i = 1;		// If stationary or moving up/down, dig at x-1.
+  if (status == STANDING)
+      setNextDir();
+  if ((status == WALKING) ||
+      ((status == STANDING) && ((nextDir == LEFT) || (nextDir == RIGHT)))) {
+      if ((direction == LEFT) && canWalkLeft())
+          i = 2;	// If walking left, dig at x-2 and stop at x-1.
+      else if ((direction == RIGHT) && canWalkRight())
+          i = 0;	// If walking right, dig at x and stop at x+1.
+  }
+  if (((*playfield)[x-i][y+1]->whatIam() == BRICK)&&
+      (((*playfield)[x-i][y]->whatIam() == HLADDER)||
+       ((*playfield)[x-i][y]->whatIam() == FREE)||
+       ((*playfield)[x-i][y]->whatIam() == HOLE)))
+    ((KGrBrick*)(*playfield)[x-i][y+1])->dig();
 }
 
 void KGrHero::digRight(){
-  if (((*playfield)[x+1][y+1]->whatIam() == BRICK)&&
-      (((*playfield)[x+1][y]->whatIam() == HLADDER)||
-       ((*playfield)[x+1][y]->whatIam() == FREE)||
-       ((*playfield)[x+1][y]->whatIam() == HOLE)))
-    ((KGrBrick*)(*playfield)[x+1][y+1])->dig();
+  int i = 1;		// If stationary or moving up/down, dig at x+1.
+  if (status == STANDING)
+      setNextDir();
+  if ((status == WALKING) ||
+      ((status == STANDING) && ((nextDir == LEFT) || (nextDir == RIGHT)))) {
+      if ((direction == LEFT) && canWalkLeft())
+          i = 0;	// If walking left, dig at x and stop at x-1.
+      else if ((direction == RIGHT) && canWalkRight())
+          i = 2;	// If walking right, dig at x+2 and stop at x+1.
+  }
+  if (((*playfield)[x+i][y+1]->whatIam() == BRICK)&&
+      (((*playfield)[x+i][y]->whatIam() == HLADDER)||
+       ((*playfield)[x+i][y]->whatIam() == FREE)||
+       ((*playfield)[x+i][y]->whatIam() == HOLE)))
+    ((KGrBrick*)(*playfield)[x+i][y+1])->dig();
 }
 
 #ifdef QT3
@@ -699,6 +732,12 @@ bool KGrHero::standOnEnemy()
 		 ((absy + 12) == enemy->gety())) &&
 		(((absx - 16) <  enemy->getx()) &&
 		 ((absx + 16) >  enemy->getx()))) {
+                if (((absy + 12) == enemy->gety()) &&
+                    (enemy->getStatus() != FALLING)) {
+                    absy = absy - rely; // Bounce back from overlap, to avoid
+                    rely = 0;           // hero-enemy mid-cycle deadlock.
+                    walkCounter = 1;
+		}
 		return true;
 	    }
 	}
@@ -870,7 +909,16 @@ void KGrEnemy::walkTimeDone ()
       default:		// Switch search direction in KGoldrunner search (only).
 			searchStatus = (searchStatus==VERTIKAL) ?
 					HORIZONTAL : VERTIKAL;
-			status = STANDING;
+
+                        // In KGoldrunner rules, if a hole opens under an enemy
+                        // who is standing and waiting to move, he should fall.
+                        if (!(canStand()||hangAtPole())) {
+                            initFall (actualPixmap, FALLDELAY);
+                        }
+                        else {
+                            status = STANDING;
+                        }
+
 			break;
     }
     // wenn die Figur genau ein Feld gelaufen ist
@@ -891,6 +939,11 @@ void KGrEnemy::walkTimeDone ()
   else {
     // A friend is in the way.  Try a new direction, but not if leaving a hole.
     Direction dirn;
+
+    // In KGoldrunner rules, change the search strategy,
+    // to avoid enemy-enemy deadlock.
+    searchStatus = (searchStatus==VERTIKAL) ? HORIZONTAL : VERTIKAL;
+
     dirn = searchbestway (x, y, herox, heroy);
     if ((dirn != direction) && ((*playfield)[x][y]->whatIam() != USEDHOLE)) {
       direction = dirn;
@@ -1672,7 +1725,7 @@ bool KGrEnemy::bumpingFriend()
     cmax = enemies->count();
     for (c = 0; c < cmax; c++) {
 	enemy = enemies->at(c);
-	if ((enemy->enemyId != this->enemyId) && (enemy->status != FALLING)) {
+	if ((enemy->enemyId != enemyId) && (enemy->status != FALLING)) {
 	    dx = enemy->getx() - absx;
 	    dy = enemy->gety() - absy;
 	    switch (direction) {
@@ -1683,7 +1736,7 @@ bool KGrEnemy::bumpingFriend()
 			return TRUE;
 		    }
 		    else if (dx >= -16) {
-			if ((dx > -16) && (this->enemyId < enemy->enemyId))
+			if ((dx > -16) && (enemyId < enemy->enemyId))
 			    return FALSE;
 			else
 			    return TRUE;	// Wait for the one in front.
@@ -1697,7 +1750,7 @@ bool KGrEnemy::bumpingFriend()
 			return TRUE;
 		    }
 		    else if (dx <= 16) {
-			if ((dx < 16) && (this->enemyId < enemy->enemyId))
+			if ((dx < 16) && (enemyId < enemy->enemyId))
 			    return FALSE;
 			else
 			    return TRUE;	// Wait for the one in front.
@@ -1711,7 +1764,7 @@ bool KGrEnemy::bumpingFriend()
 			return TRUE;
 		    }
 		    else if (dy >= -16) {
-			if ((dy > -16) && (this->enemyId < enemy->enemyId))
+			if ((dy > -16) && (enemyId < enemy->enemyId))
 			    return FALSE;
 			else
 			    return TRUE;	// Wait for the one above.
@@ -1725,7 +1778,7 @@ bool KGrEnemy::bumpingFriend()
 			return TRUE;
 		    }
 		    else if (dy <= 16) {
-			if ((dy < 16) && (this->enemyId < enemy->enemyId))
+			if ((dy < 16) && (enemyId < enemy->enemyId))
 			    return FALSE;
 			else
 			    return TRUE;	// Wait for the one below.
