@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Ian Wadham and Marco Krger                     *
- *   ianw@netspace.net.au                                                  *
+ *   ianw2@optusnet.com.au                                                  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -111,6 +111,8 @@ void KGrGame::startLevel (int startingAt, int requestedLevel)
     int selectedLevel = selectLevel (startingAt, requestedLevel);
     if (selectedLevel > 0) {	// If OK, start the selected game and level.
  	newGame (selectedLevel, selectedGame);
+    } else {
+      level = 0;
     }
 }
 
@@ -157,8 +159,12 @@ void KGrGame::herosDead()
 
 void KGrGame::finalBreath()
 {
-    enemyCount = 0;		// Hero is dead: re-start the level.
-    loadLevel (level);
+    // Fix bug 95202:	Avoid re-starting if the player selected
+    //			edit mode before the 1.5 seconds were up.
+    if (! editMode) {
+	enemyCount = 0;		// Hero is dead: re-start the level.
+	loadLevel (level);
+    }
     KGrObject::frozen = FALSE;	// Unfreeze the game, but don't move yet.
 }
 
@@ -481,7 +487,8 @@ int KGrGame::loadLevel (int levelNo)
   }
 
   // Put the mouse pointer on the hero.
-  view->setMousePos (startI, startJ);
+  if (mouseMode)
+      view->setMousePos (startI, startJ);
 
   // Connect play-mode slot to signal from "view".
   connect (view, SIGNAL(mouseClick(int)), SLOT(doDig(int)));
