@@ -1,6 +1,4 @@
 /***************************************************************************
-                          prompt.cpp  -  description
-                             -------------------
     begin                : Fri May 19 2000
     copyright            : (C) 2000 by Roman Merzlyakov
     email                : roman@sbrf.barrt.ru
@@ -16,6 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
 #include <qpainter.h>
 #include "prompt.h"
 #include "prompt.moc"
@@ -52,14 +51,14 @@ void LinesPrompt::paintEvent( QPaintEvent* )
 {
   QPainter paint( this );
   if(PromptEnabled){
-    paint.drawPixmap(0,          0, *(bPainter->GetNormalBall(cb[0])) );
-    paint.drawPixmap(CELLSIZE,   0, *(bPainter->GetNormalBall(cb[1])) );
-    paint.drawPixmap(2*CELLSIZE, 0, *(bPainter->GetNormalBall(cb[2])) );
+    paint.drawPixmap(0,          0, bPainter->GetNormalBall(cb[0]) );
+    paint.drawPixmap(CELLSIZE,   0, bPainter->GetNormalBall(cb[1]) );
+    paint.drawPixmap(2*CELLSIZE, 0, bPainter->GetNormalBall(cb[2]) );
   }
   else{
-    paint.drawPixmap(0,          0, *(bPainter->GetBackgroundPix()) );
-    paint.drawPixmap(CELLSIZE,   0, *(bPainter->GetBackgroundPix()) );
-    paint.drawPixmap(2*CELLSIZE, 0, *(bPainter->GetBackgroundPix()) );
+    paint.drawPixmap(0,          0, bPainter->GetBackgroundPix() );
+    paint.drawPixmap(CELLSIZE,   0, bPainter->GetBackgroundPix() );
+    paint.drawPixmap(2*CELLSIZE, 0, bPainter->GetBackgroundPix() );
   }
 }
 
