@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.h 401425 2005-03-28 21:52:58Z aacid $
+    $Id: kmahjongg.h 465369 2005-09-29 14:33:08Z mueller $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -21,7 +21,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -93,7 +93,6 @@ private slots:
 protected:
   void setupKAction();
   void setupStatusBar();
-  void enableItem(int item, bool state){}
 
 private:
   // number of seconds since the start of the game
